package com.datacloudsec.scan.tasks.scheduler.job.task;

import com.datacloudsec.scan.dao.AlarmlogMapper;
import com.datacloudsec.scan.dao.EngineMapper;
import com.datacloudsec.scan.dao.SysBugMapper;
import com.datacloudsec.scan.dao.TaskBaseMapper;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.service.IEngine;
import com.datacloudsec.scan.service.IPwd;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.service.impl.EngineService;
import com.datacloudsec.scan.service.impl.PwdService;
import com.datacloudsec.scan.tasks.scheduler.job.AlermJob;
import com.datacloudsec.utils.FtpUtil;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.MybatisUtil;
import com.datacloudsec.utils.ObjectUtil;
import java.util.Date;
import java.util.List;
import java.util.Map;
import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.ibatis.session.SqlSession;
import org.apache.log4j.Logger;

/* loaded from: com_datacloudsec_scan_tasks_scheduler_job_task.jar:com/datacloudsec/scan/tasks/scheduler/job/task/PwdTask.class */
public class PwdTask {
    private static final Logger LOG = Logger.getLogger(PwdTask.class);
    private static IPwd pwdService = (IPwd) InstanceUtil.newServiceInstance(PwdService.class);
    private static TaskBaseMapper taskBaseMapper = (TaskBaseMapper) InstanceUtil.newDaoInstance(TaskBaseMapper.class);
    private static AlarmlogMapper alarmlogMapper = (AlarmlogMapper) InstanceUtil.newDaoInstance(AlarmlogMapper.class);
    private static IEngine engine = new EngineService();
    private static final int PWDS_LIMIT = 100;

    public static void pwdScanSync(Map<String, Object> device) {
        if (device == null) {
            return;
        }
        SqlSession session = null;
        try {
            try {
                Integer deviceid = ObjectUtil.getInt(device.get("id"));
                int offset1 = ObjectUtil.getInt(device.get("offset1")).intValue();
                Map<String, Object> result = engine.pwdGetResult(ObjectUtil.getString(device.get("engineId"), (String) null), ObjectUtil.getInt(device.get("localEid"), 0), offset1, PWDS_LIMIT);
                String error = ObjectUtil.getString(result.get("error"), (String) null);
                List<Map<String, Object>> pwds = (List) result.get("pwds");
                session = MybatisUtil.sqlSessionFactory.openSession(true);
                EngineMapper engMapper = (EngineMapper) session.getMapper(EngineMapper.class);
                SysBugMapper sysBugMapper = (SysBugMapper) session.getMapper(SysBugMapper.class);
                Integer scanCount = Integer.valueOf(ObjectUtil.getInt(device.get("scanCount"), 0));
                if (scanCount.intValue() == 1) {
                    if (pwds != null && pwds.size() > 0) {
                        engMapper.sysAddPwds1(deviceid, pwds);
                    }
                } else if (pwds != null && pwds.size() > 0) {
                    engMapper.sysAddPwds(deviceid, pwds);
                }
                double progress = ObjectUtil.getDouble(result.get("progress"), 0.0d);
                Integer status = null;
                if (progress == 100.0d && (pwds == null || pwds.size() == 0)) {
                    status = 2;
                    if (scanCount.intValue() != 1) {
                        sysBugMapper.delSysPwd(deviceid);
                        engMapper.sysCopyPwd(deviceid);
                        sysBugMapper.delSysPwd2(deviceid);
                    }
                    Integer pwdCount = sysBugMapper.pwdCountByDev(deviceid);
                    sysBugMapper.insertPwdStatics(pwdCount, new Date(), deviceid);
                }
                if (StringUtils.isNotBlank(error)) {
                    status = 3;
                }
                engMapper.updateScanInfo(deviceid, status, Double.valueOf(progress), (Integer) null, (Integer) null, error == null ? "" : error, Integer.valueOf(offset1 + (pwds == null ? 0 : pwds.size())), (Integer) null, (Integer) null, new Date(), false);
                session.commit();
                if (status != null && (status.intValue() == 2 || status.intValue() == 3)) {
                    List<Map<String, Object>> queryPwdBug = alarmlogMapper.queryPwdBug(deviceid);
                    if (CollectionUtils.isNotEmpty(queryPwdBug)) {
                        alarmlogMapper.delAlarmlogByTime();
                        alarmlogMapper.batchInsert(queryPwdBug);
                    }
                    Map<String, Object> waitingDev = engMapper.getWaitingDev(3, deviceid);
                    if (waitingDev != null && waitingDev.size() > 0) {
                        pwdService.start(ObjectUtil.getInt(waitingDev.get("id")));
                    }
                    if (ObjectUtil.getInt(device.get("alarmType"), 0) == 1 || StringUtils.isNotBlank(ObjectUtil.getString(device.get("val2"), ""))) {
                        AlermJob.alermDevice(device);
                    }
                    Task task = taskBaseMapper.getTaskById(ObjectUtil.getInt(device.get("taskId")));
                    FtpUtil.reportUpload(task, device, (String) IReport.REPORT_CHK.get("pwd"), "pwd");
                }
                if (session != null) {
                    session.close();
                }
            } catch (Exception e) {
                if (session != null) {
                    session.rollback();
                }
                LOG.error("系统引擎同步出错", e);
                if (session != null) {
                    session.close();
                }
            }
        } catch (Throwable th) {
            if (session != null) {
                session.close();
            }
            throw th;
        }
    }
}
